from django.conf.urls import patterns, include

from rest_framework import routers

from inventory import api

router = routers.DefaultRouter()
router.register(r'users', api.UserViewSet)
router.register(r'objects', api.InventoryObjectViewSet)
router.register(r'ipv4networks', api.IPv4NetworkViewSet)
router.register(r'attributes', api.InventoryObjectAttributeViewSet)
router.register(r'labels', api.InventoryObjectLabelViewSet)

urlpatterns = patterns(
    '',
    (r'^$', 'inventory.views.objectlist'),
    (r'^api\/v1\/import\.json$', 'inventory.views.api_import'),
    (r'^api\/v1\/lookup\.json$', 'inventory.views.api_lookup'),
    (r'^api\/v1\/object\/list\.json$', 'inventory.views.api_object_list'),
    (r'^api\/v1\/object\/list\/inventory\.json$',
        'inventory.views.api_object_list_inventory'),
    (r'^api/v1\/search/suggest.json', 'inventory.views.api_suggest'),

    # API v2 views
    (r'^api\/v2\/', include(router.urls)),
    (r'^account\/applications/(?P<applicationid>[0-9]+)\.html',
        'security.views.application'),
    (r'^account\/applications\.html$', 'security.views.applications'),
    (r'^account\/profile\.html$', 'security.views.profile'),
    (r'^export\/object\/inventory\.csv',
        'inventory.views.export_object_inventory'),
    (r'^inventory\.html$', 'inventory.views.objectlist'),
    (r'^ipv4network\/(?P<networkid>[0-9]+)\.html$',
        'inventory.views.ipv4network'),
    (r'^ipv4networks\.html$', 'inventory.views.ipv4networks'),
    (r'^labels\.html$', 'inventory.views.labels'),
    (r'^location\/(?P<location>[a-z0-9_-]+)\.html$',
        'inventory.views.location'),
    (r'^locations\.html$', 'inventory.views.locations'),
    (r'^l2networks\.html$', 'inventory.views.l2networks'),
    (r'^reports\/basic\.html$', 'reports.views.basic'),
    (r'^search\.html$', 'inventory.views.search'),
    (r'^object\/(?P<object_pk>[0-9]+)\.html$', 'inventory.views.object'),
    (r'^account\/login\.html$', 'security.views.login_view'),
    (r'^account\/logout\.html$', 'security.views.logout_view'),
)
